@@ -1,6 +1,6 @@
 /* arp.c - ARP state machine */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
@@ -496,6 +496,17 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
 	  "(%d -> %d)",entry->itf->number,itf->number);
     if (!entry->addr) entry->addr = alloc(sizeof(*addr));
     *entry->addr = *addr;
+    if (merge) {
+	ENTRY *incoming;
+
+	while ((incoming = lookup_incoming(addr))) {
+	    STOP_TIMER(incoming);
+	    Q_REMOVE(unknown_incoming,incoming);
+	    incoming->vccs->entry = entry;
+	    Q_INSERT_HEAD(entry->vccs,incoming->vccs);
+	    free(incoming);
+	}
+    }
     for (walk = entry->vccs; walk; walk = walk->next)
 	if (!walk->connecting)
 	    if (set_ip(walk->fd,ip) < 0)
