@@ -236,7 +236,7 @@ typedef void (*ARP_XMT_CALLBACK) (HANDLE    lc_elan_handle,
 *
 --*/
 typedef void (*FLUSH_XMT_CALLBACK) (HANDLE    lc_elan_handle,
-                                    ADDR_ATM  addr_atm,
+                                    unsigned char*  addr_atm,
                                     HANDLE    esi_handle);
 
 /*++
@@ -565,7 +565,6 @@ void la_arp_update (HANDLE    la_elan_handle,
 *   requested MAC address may now be forwarded to the data-direct VCC.
 --*/
 void la_flush_complete (HANDLE   la_elan_handle,
-                        ADDR_ATM addr_atm,
                         UINT32   tran_id);
 
 /*++
@@ -595,3 +594,4 @@ void la_flush_complete (HANDLE   la_elan_handle,
 void la_topology_change_set (HANDLE  la_elan_handle,
                              BOOLEAN topology_change_flag);
 
+void kernel_flush_xmt(unsigned char *to_pass);
