@@ -158,7 +158,7 @@ static int encode_nsap(char *buf,const unsigned char *addr)
 }
 
 
-int cc_len(int p0,int p1)
+static int cc_len(int p0,int p1)
 {
     static char *cc_table = NULL;
     FILE *file;
