@@ -201,9 +201,9 @@ static void dump_status(FILE *file,const char *banner)
 
     if (sockets) fprintf(file,"%s\n\n",banner);
     for (walk = sockets; walk; walk = walk->next) {
-	fprintf(file,"0x%lx: %s, CR 0x%06lX, PVC %d.%d.%d\n",(unsigned long)
-	  walk->id,state_name[walk->state],walk->call_ref,
-	  walk->pvc.sap_addr.itf,walk->pvc.sap_addr.vpi,walk->pvc.sap_addr.vci);
+	fprintf(file,"0x%lx: %s, CR 0x%06lX, PVC %d.%d.%d\n",walk->id,
+	  state_name[walk->state],walk->call_ref,walk->pvc.sap_addr.itf,
+	  walk->pvc.sap_addr.vpi,walk->pvc.sap_addr.vci);
         dump_sap(file,"local ",walk->local);
         dump_sap(file,"remote",walk->remote);
     }
@@ -328,7 +328,8 @@ static void trace_on_exit(int status,void *dummy)
 static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s [ -b ] [ -c config_file ] [ -d ] [ -D dump_dir ]"
-      " [ -l logfile ] [ -n ] [ -N ] [ -q qos ] [ -t trace_length ]\n",name);
+      " [ -l logfile ] [ -n ] [ -N ] [ -q qos ] [ -t trace_length ] "
+      "[ [itf.]vpi.vci ]\n",name);
     exit(1);
 }
 
@@ -404,7 +405,12 @@ int main(int argc,char **argv)
 	    default:
 		usage(argv[0]);
 	}
-    if (optind != argc) usage(argv[0]);
+    if (optind == argc-1) {
+	if (text2atm(argv[optind],(struct sockaddr *) &signaling_pvc,
+	  sizeof(signaling_pvc),T2A_PVC) < 0)
+	    diag(COMPONENT,DIAG_FATAL,"text2atm \"%s\": failed",argv[optind]);
+    }
+    else if (optind != argc) usage(argv[0]);
     diag(COMPONENT,DIAG_INFO,"Linux ATM signaling "
 #ifdef UNI30
       "UNI 3.0"
