@@ -1,6 +1,6 @@
 /* io.c - I/O operations */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdio.h>
@@ -121,11 +121,12 @@ static int open_signaling(void)
     struct atm_qos qos;
     int s;
 
-    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL5)) < 0) {
+    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,0)) < 0) {
 	perror("socket");
 	return -1;
     }
     memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL5;
     qos.rxtp.max_sdu = qos.txtp.max_sdu = MAX_Q_MSG;
     if (sig_qos) {
 	if (text2qos(sig_qos,&qos,T2Q_DEFAULTS) < 0) {
@@ -308,3 +309,46 @@ void poll_loop(void)
 	}
     }
 }
+
+
+/*
+ * The allocation strategy could be improved as follows: we should try
+ * vci = prev_vci++  first and only resort to ATM_VCI_ANY if that fails several
+ * times (and we should actually skip over those which are in use by SVCs. This
+ * way we avoid using VCIs that just became available. Doing it "right" seems
+ * to be getting complex, though.
+ */
+
+
+int get_pvc(int itf,int *vci)
+{
+    struct sockaddr_atmpvc addr;
+    struct atm_qos qos;
+    int s,error;
+
+    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,0)) < 0)
+        diag(COMPONENT,DIAG_FATAL,"get_pvc: %s",strerror(errno));
+    memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL5;
+    qos.rxtp.traffic_class = qos.txtp.traffic_class = ATM_UBR;
+    if (setsockopt(s,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
+	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
+    memset(&addr,0,sizeof(addr));
+    addr.sap_family = AF_ATMPVC;
+    addr.sap_addr.itf = itf;
+    addr.sap_addr.vpi = 0; /* @@@ */
+    addr.sap_addr.vci = ATM_VCI_ANY;
+    error = 0;
+    if (bind(s,(struct sockaddr *) &addr,sizeof(addr)) < 0) error = errno;
+    else {
+	int size;
+
+	size = sizeof(addr);
+	if (getsockname(s,(struct sockaddr *) &addr,&size) < 0)
+	    diag(COMPONENT,DIAG_FATAL,"get_pvc: %s",strerror(errno));
+	*vci = addr.sap_addr.vci;
+	return s;
+    }
+    (void) close(s);
+    return -error;
+}
