@@ -1,6 +1,6 @@
 /* io.h - I/O operations */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #ifndef IO_H
@@ -33,4 +33,6 @@ void to_net(void *msg,int size);
 
 int get_addr(int itf);
 
+int get_pvc(int itf,int *vci);
+
 #endif
