@@ -1,6 +1,6 @@
 /* kernel.c - Processing of incoming kernel messages */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
@@ -24,9 +24,6 @@
 #define COMPONENT "KERNEL"
 
 
-extern int assign_vci;
-
-
 static int send_setup(SOCKET *sock)
 {
     static unsigned long call_ref = 0;
@@ -74,11 +71,18 @@ static int send_setup(SOCKET *sock)
 	q_write(&dsc,QF_cgpn,(void *) local->sas_addr.prv,ATM_ESA_LEN);
     }
     if (net) {
-	q_assign(&dsc,QF_vpi,0);
-	q_assign(&dsc,QF_vci,assign_vci); /* @@@ */
+	int vci;
+
+	vci = get_vci(0);
+	if (vci < 0) {
+	    (void) q_close(&dsc);
+	    return vci;
+	}
+	q_assign(&dsc,QF_vpi,0); /* @@@ */
+	q_assign(&dsc,QF_vci,vci);
 	sock->pvc.sap_addr.itf = get_itf(0);
 	sock->pvc.sap_addr.vpi = 0;
-	sock->pvc.sap_addr.vci = assign_vci++;
+	sock->pvc.sap_addr.vci = vci;
     }
     if ((size = q_close(&dsc)) < 0) error = -EINVAL;
     else if (!error) to_signaling(q_buffer,size);
@@ -136,10 +140,6 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
     switch (msg->type) {
 	case as_bind: /* only in NULL state */
 	    if (sock) break;
-	    if (msg->aal != ATM_AAL5) {
-		SEND_ERROR(msg->vcc,-EINVAL);
-		return;
-	    }
 	    if (!*msg->svc.sas_addr.pub && !*msg->svc.sas_addr.prv)
 #ifdef BE_PICKY_ABOUT_BINDING_LOCAL_WILDCARD_ADDRESSES
 		if (local_addr[0].state != ls_same)
@@ -216,6 +216,10 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 		struct sockaddr_atmsvc *sap;
 
 		if (sock) break;
+		if (msg->qos.aal != ATM_AAL5) {
+		    SEND_ERROR(msg->vcc,-EINVAL);
+		    return;
+		}
 		sap = sap_copy(&msg->svc);
 		if (lookup_sap(sap,&msg->qos,NULL,NULL)) {
 		    free(sap);
@@ -354,9 +358,9 @@ void from_kernel(struct atmsvc_msg *msg,int size)
 	    if (msg->listen_vcc == curr->id && curr->state == ss_listening)
 		break;
     }
-    diag(COMPONENT,DIAG_DEBUG,"FROM KERNEL: %s for socket 0x%lx (0x%lx/0x%lx) "
-      "in state %s",as_name[msg->type],(unsigned long) curr,msg->vcc,
-      msg->listen_vcc,state_name[curr ? curr->state : ss_null]);
+    diag(COMPONENT,DIAG_DEBUG,"FROM KERNEL: %s for socket 0x%p (0x%lx/0x%lx) "
+      "in state %s",as_name[msg->type],curr,msg->vcc,msg->listen_vcc,
+      state_name[curr ? curr->state : ss_null]);
     msg->svc.sas_addr.blli = msg->local.sas_addr.blli = NULL;
     bllis = msg2bllis(size);
     this = &msg->svc.sas_addr.blli;
