@@ -1,11 +1,12 @@
 /* proto.c - Common protocol functions and structures */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdarg.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <unistd.h>
 #include <string.h>
 
 #include "atmd.h"
@@ -76,16 +77,15 @@ void free_sock(SOCKET *sock)
 {
     SOCKET **walk;
 
-    diag(COMPONENT,DIAG_DEBUG,"freeing socket 0x%lx@0x%lx",sock->id,
-      (unsigned long) sock);
+    diag(COMPONENT,DIAG_DEBUG,"freeing socket 0x%lx@0x%p",sock->id,sock);
     for (walk = &sockets; *walk != sock; walk = &(*walk)->next);
     if (!*walk)
 	diag(COMPONENT,DIAG_FATAL,
 	  "INTERNAL ERROR: freeing non-existing socket 0x%lx",sock->id);
     *walk = sock->next;
     if (sock->conn_timer) {
-	diag(COMPONENT,DIAG_ERROR,"socket 0x%lx has timer (0x%lx) running",
-	  sock->id,(unsigned long) sock->conn_timer->callback);
+	diag(COMPONENT,DIAG_ERROR,"socket 0x%lx has timer (0x%p) running",
+	  sock->id,sock->conn_timer->callback);
 	stop_timer(sock->conn_timer);
     }
     if (sock->listen)
@@ -264,6 +264,24 @@ void q_report(int severity,const char *msg,...)
 }
 
 
+int get_vci(int itf)
+{
+    SOCKET *walk;
+    int s,vci;
+
+    s = get_pvc(itf,&vci);
+    if (s < 0) return s;
+    for (walk = sockets; walk; walk = walk->next)
+	if (walk->pvc.sap_addr.vci == vci) {
+	    vci = get_vci(itf); /* this recursion will keep all the busy ones
+				   open until we return */
+	    break;
+	}
+    (void) close(s);
+    return vci;
+}
+
+
 typedef struct _vpci {
     int vpci;
     int itf;
