@@ -1,6 +1,6 @@
 /* proto.h - Common protocol functions and structures */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #ifndef PROTO_H
@@ -105,6 +105,8 @@ const char *mid2name(unsigned char mid);
 void set_error(SOCKET *sock,int code);
 void send_close(SOCKET *sock);
 
+int get_vci(int itf);
+
 void enter_vpci(int vpci,int itf);
 int get_itf(int *vpci);
 void init_addr(void);
