@@ -30,13 +30,11 @@
 extern const char *cause_text[]; /* from mess.c */
 
 
-int assign_vci = 42; /* assigning VCIs from here on if acting as network */
-
 static Q_DSC in_dsc;
 static TIMER *t309 = NULL;
 
 
-static void send_call_proceeding(SOCKET *sock)
+static int send_call_proceeding(SOCKET *sock)
 {
     Q_DSC dsc;
     int size;
@@ -45,14 +43,22 @@ static void send_call_proceeding(SOCKET *sock)
     q_assign(&dsc,QF_msg_type,QMSG_CALL_PROC);
     q_assign(&dsc,QF_call_ref,sock->call_ref);
     if (net) {
-	q_assign(&dsc,QF_vpi,0);
-	q_assign(&dsc,QF_vci,assign_vci); /* @@@ */
+	int vci;
+
+	vci = get_vci(0);
+	if (vci < 0) {
+	    (void) q_close(&dsc);
+	    return vci;
+	}
+	q_assign(&dsc,QF_vpi,0); /* @@@ */
+	q_assign(&dsc,QF_vci,vci);
 	sock->pvc.sap_addr.itf = signaling_pvc.sap_addr.itf;
 	sock->pvc.sap_addr.vpi = 0;
-	sock->pvc.sap_addr.vci = assign_vci++;
+	sock->pvc.sap_addr.vci = vci;
     }
     if (sock->ep_ref >= 0) q_assign(&dsc,QF_ep_ref,sock->ep_ref);
     if ((size = q_close(&dsc)) >= 0) to_signaling(q_buffer,size);
+    return 0;
 }
 
 
@@ -69,6 +75,7 @@ static void setup_call(unsigned long call_ref)
     sock = lookup_sap(sap,&qos,&new_sap,&new_qos);
     if (!sock || new_sap) free(sap);
     else new_sap = sap; /* @@@ should strip extra BLLIs */
+    new_qos.aal = ATM_AAL5; /* hack @@@ */
     if (!sock) {
 	send_release_complete(call_ref,ATM_CV_INCOMP_DEST); /* @@@ dunno */
 	return;
@@ -82,7 +89,16 @@ static void setup_call(unsigned long call_ref)
 #ifdef CISCO
     else
 #endif
-    send_call_proceeding(this);
+    {
+	int error;
+
+	error = send_call_proceeding(this);
+	if (error) {
+	    free_sock(this);
+	    send_release_complete(call_ref,ATM_CV_NO_CI);
+	    return;
+	}
+    }
     this->local = new_sap;
     this->qos = new_qos;
     /* if (sock->local) *this->local->sas_addr = sock->local->sas_addr; ??? */
